==> qtjambi-debuginfo-macos-5.15.18.jar: sources/QtJambiWidgets/QStyleOptionSizeGrip_shell.cpp <==
#include "QStyleOptionSizeGrip_shell.h"
#include <QtJambi/Cast>

void deleter_QStyleOptionSizeGrip(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QStyleOptionSizeGrip")
    QStyleOptionSizeGrip *_ptr = reinterpret_cast<QStyleOptionSizeGrip *>(ptr);
    if(isShell){
        delete static_cast<QStyleOptionSizeGrip_shell*>(_ptr);
    }else{
        QtJambiAPI::registerNonShellDeletion(ptr);
        delete _ptr;
    }
}

QtJambiShell* QStyleOptionSizeGrip_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QStyleOptionSizeGrip_shell) ); }

jmethodID QStyleOptionSizeGrip_shell::__shell_javaMethod(int pos) const { return QStyleOptionSizeGrip_shell::__shell()->javaMethod(typeid(QStyleOptionSizeGrip), pos); }

// emitting (writeShellConstructor)
QStyleOptionSizeGrip_shell::QStyleOptionSizeGrip_shell()
    : QStyleOptionSizeGrip()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QStyleOptionSizeGrip::QStyleOptionSizeGrip_shell()", QStyleOptionSizeGrip_shell::__shell())
    QStyleOptionSizeGrip_shell::__shell()->constructed(typeid(QStyleOptionSizeGrip));
}

QStyleOptionSizeGrip_shell::QStyleOptionSizeGrip_shell(const QStyleOptionSizeGrip& other0)
    : QStyleOptionSizeGrip(other0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QStyleOptionSizeGrip::QStyleOptionSizeGrip_shell(const QStyleOptionSizeGrip& other0)", QStyleOptionSizeGrip_shell::__shell())
    QStyleOptionSizeGrip_shell::__shell()->constructed(typeid(QStyleOptionSizeGrip));
}

// emitting (writeShellDestructor)
QStyleOptionSizeGrip_shell::~QStyleOptionSizeGrip_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QStyleOptionSizeGrip::~QStyleOptionSizeGrip()", QStyleOptionSizeGrip_shell::__shell())
    QStyleOptionSizeGrip_shell::__shell()->destructed(typeid(QStyleOptionSizeGrip));
}

void QStyleOptionSizeGrip_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QStyleOptionSizeGrip_shell*>(ptr)->QStyleOptionSizeGrip_shell::__shell()->tryDeleteShell(typeid(QStyleOptionSizeGrip));
}

// emitting Virtual overrides (virtualFunctions)
// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
// emitting (writeConstructors)
// new QStyleOptionSizeGrip()
void __qt_construct_QStyleOptionSizeGrip_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QStyleOptionSizeGrip()")
    Q_UNUSED(__java_arguments)
    QStyleOptionSizeGrip *__qt_this = new(__qtjambi_ptr) QStyleOptionSizeGrip_shell();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// new QStyleOptionSizeGrip(QStyleOptionSizeGrip)
void __qt_construct_QStyleOptionSizeGrip_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QStyleOptionSizeGrip(QStyleOptionSizeGrip)")
    jobject other0 = __java_arguments[0].l;
    const QStyleOptionSizeGrip& __qt_other0 = qtjambi_cast<const QStyleOptionSizeGrip& >(__jni_env, other0);
    QStyleOptionSizeGrip *__qt_this = new(__qtjambi_ptr) QStyleOptionSizeGrip_shell(__qt_other0);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QStyleOptionSizeGrip_shell
void __qt_destruct_QStyleOptionSizeGrip(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QStyleOptionSizeGrip")
    reinterpret_cast<QStyleOptionSizeGrip_shell*>(ptr)->~QStyleOptionSizeGrip_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QStyleOptionSizeGrip::QStyleOptionSizeGrip()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleOptionSizeGrip_initialize_1native__Lio_qt_widgets_QStyleOptionSizeGrip_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QStyleOptionSizeGrip::QStyleOptionSizeGrip()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QStyleOptionSizeGrip_0, sizeof(QStyleOptionSizeGrip_shell), typeid(QStyleOptionSizeGrip), true, &deleter_QStyleOptionSizeGrip, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QStyleOptionSizeGrip::QStyleOptionSizeGrip(QStyleOptionSizeGrip)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleOptionSizeGrip_initialize_1native__Lio_qt_widgets_QStyleOptionSizeGrip_2Lio_qt_widgets_QStyleOptionSizeGrip_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QStyleOptionSizeGrip::QStyleOptionSizeGrip(QStyleOptionSizeGrip)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QStyleOptionSizeGrip_1, sizeof(QStyleOptionSizeGrip_shell), typeid(QStyleOptionSizeGrip), true, &deleter_QStyleOptionSizeGrip, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QStyleOptionSizeGrip::operator=(QStyleOptionSizeGrip)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleOptionSizeGrip_assign_1native_1cref_1QStyleOptionSizeGrip__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID arg__1)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QStyleOptionSizeGrip *__qt_this = QtJambiAPI::objectFromNativeId<QStyleOptionSizeGrip>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QStyleOptionSizeGrip::operator=(QStyleOptionSizeGrip)", __qt_this)
        const QStyleOptionSizeGrip& __qt_arg__1 = QtJambiAPI::valueReferenceFromNativeId<QStyleOptionSizeGrip>(arg__1);
        (*__qt_this) = __qt_arg__1;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleOptionSizeGrip_setCorner_1native_1cref_1Qt_1Corner__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint corner0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QStyleOptionSizeGrip *__qt_this = QtJambiAPI::objectFromNativeId<QStyleOptionSizeGrip>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        Qt::Corner __qt_corner0 = qtjambi_cast<Qt::Corner>(__jni_env, corner0);
        __qt_this->corner = Qt::Corner(__qt_corner0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleOptionSizeGrip_corner_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QStyleOptionSizeGrip *__qt_this = QtJambiAPI::objectFromNativeId<QStyleOptionSizeGrip>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const Qt::Corner&  __qt_value = __qt_this->corner;
        __java_return_value = __qt_value;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleOptionSizeGrip_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QStyleOptionSizeGrip *__qt_this = QtJambiAPI::objectFromNativeId<QStyleOptionSizeGrip>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QStyleOptionSizeGrip(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QStyleOptionSizeGrip>("QStyleOptionSizeGrip", "io/qt/widgets/QStyleOptionSizeGrip");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QStyleOptionSizeGrip, {
        ConstructorInfo(&__qt_construct_QStyleOptionSizeGrip_0, nullptr)
       ,ConstructorInfo(&__qt_construct_QStyleOptionSizeGrip_1, "Lio/qt/widgets/QStyleOptionSizeGrip;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QStyleOptionSizeGrip);
    registerMetaType<QStyleOptionSizeGrip>("QStyleOptionSizeGrip");
    registerSizeOfShell(typeId, sizeof(QStyleOptionSizeGrip_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerPolymorphyHandler(typeid(QStyleOptionComplex), typeId, [](void *ptr, qintptr& offset) -> bool {
            QStyleOptionComplex *object = reinterpret_cast<QStyleOptionComplex *>(ptr);
            Q_ASSERT(object);
            offset = 0;
            bool _result = false;
            QTJAMBI_TRY_ANY { // cast from baseclass
                _result = object->type == QStyleOptionSizeGrip::Type;
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerPolymorphyHandler(typeid(QStyleOption), typeId, [](void *ptr, qintptr& offset) -> bool {
            QStyleOption *object = reinterpret_cast<QStyleOption *>(ptr);
            Q_ASSERT(object);
            offset = 0;
            bool _result = false;
            QTJAMBI_TRY_ANY { // cast from baseclass
                _result = object->type == QStyleOptionSizeGrip::Type;
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-macos-6.7.2.jar: sources/QtJambiWidgets/QStyleOptionSizeGrip_shell.cpp <==
#include "QStyleOptionSizeGrip_shell.h"
#include <QtJambi/Cast>

void deleter_QStyleOptionSizeGrip(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QStyleOptionSizeGrip")
    QStyleOptionSizeGrip *_ptr = reinterpret_cast<QStyleOptionSizeGrip *>(ptr);
    if(isShell){
        delete static_cast<QStyleOptionSizeGrip_shell*>(_ptr);
    }else{
        QtJambiAPI::registerNonShellDeletion(ptr);
        delete _ptr;
    }
}

QtJambiShell* QStyleOptionSizeGrip_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QStyleOptionSizeGrip_shell) ); }

// emitting (writeShellDestructor)
QStyleOptionSizeGrip_shell::~QStyleOptionSizeGrip_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QStyleOptionSizeGrip::~QStyleOptionSizeGrip()", this)
    QStyleOptionSizeGrip_shell::__shell()->destructed(typeid(QStyleOptionSizeGrip));
}

// emitting (writeShellConstructor)
QStyleOptionSizeGrip_shell::QStyleOptionSizeGrip_shell()
    : QStyleOptionSizeGrip()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QStyleOptionSizeGrip::QStyleOptionSizeGrip_shell()", this)
    QStyleOptionSizeGrip_shell::__shell()->constructed(typeid(QStyleOptionSizeGrip));
}

QStyleOptionSizeGrip_shell::QStyleOptionSizeGrip_shell(const QStyleOptionSizeGrip& other0)
    : QStyleOptionSizeGrip(other0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QStyleOptionSizeGrip::QStyleOptionSizeGrip_shell(const QStyleOptionSizeGrip& other0)", this)
    QStyleOptionSizeGrip_shell::__shell()->constructed(typeid(QStyleOptionSizeGrip));
}

void QStyleOptionSizeGrip_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QStyleOptionSizeGrip_shell*>(ptr)->QStyleOptionSizeGrip_shell::__shell()->tryDeleteShell(typeid(QStyleOptionSizeGrip));
}

// emitting Virtual overrides (virtualFunctions)
// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
// emitting (writeConstructors)
// new QStyleOptionSizeGrip()
void __qt_construct_QStyleOptionSizeGrip(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QStyleOptionSizeGrip()")
    Q_UNUSED(__java_arguments)
    QStyleOptionSizeGrip *__qt_this = new(__qtjambi_ptr) QStyleOptionSizeGrip_shell();
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
}

// QStyleOptionSizeGrip::QStyleOptionSizeGrip()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleOptionSizeGrip_initialize_1native__Lio_qt_widgets_QStyleOptionSizeGrip_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QStyleOptionSizeGrip::QStyleOptionSizeGrip()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QStyleOptionSizeGrip, sizeof(QStyleOptionSizeGrip_shell), typeid(QStyleOptionSizeGrip), 0, true, &deleter_QStyleOptionSizeGrip, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QStyleOptionSizeGrip(QStyleOptionSizeGrip)
void __qt_construct_QStyleOptionSizeGrip_cref_QStyleOptionSizeGrip(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QStyleOptionSizeGrip(QStyleOptionSizeGrip)")
    jobject other0 = __java_arguments[0].l;
    const QStyleOptionSizeGrip& __qt_other0 = qtjambi_cast<const QStyleOptionSizeGrip&>(__jni_env, other0);
    QStyleOptionSizeGrip *__qt_this = new(__qtjambi_ptr) QStyleOptionSizeGrip_shell(__qt_other0);
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
}

// QStyleOptionSizeGrip::QStyleOptionSizeGrip(QStyleOptionSizeGrip)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleOptionSizeGrip_initialize_1native__Lio_qt_widgets_QStyleOptionSizeGrip_2Lio_qt_widgets_QStyleOptionSizeGrip_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QStyleOptionSizeGrip::QStyleOptionSizeGrip(QStyleOptionSizeGrip)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QStyleOptionSizeGrip_cref_QStyleOptionSizeGrip, sizeof(QStyleOptionSizeGrip_shell), typeid(QStyleOptionSizeGrip), 0, true, &deleter_QStyleOptionSizeGrip, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QStyleOptionSizeGrip_shell
void __qt_destruct_QStyleOptionSizeGrip(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QStyleOptionSizeGrip")
    reinterpret_cast<QStyleOptionSizeGrip_shell*>(ptr)->~QStyleOptionSizeGrip_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QStyleOptionSizeGrip::operator=(QStyleOptionSizeGrip)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleOptionSizeGrip_assign_1native_1cref_1QStyleOptionSizeGrip__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID arg__1)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QStyleOptionSizeGrip *__qt_this = QtJambiAPI::objectFromNativeId<QStyleOptionSizeGrip>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QStyleOptionSizeGrip::operator=(QStyleOptionSizeGrip)", __this_nativeId)
        const QStyleOptionSizeGrip& __qt_arg__1 = QtJambiAPI::valueReferenceFromNativeId<QStyleOptionSizeGrip>(arg__1);
        (*__qt_this) = __qt_arg__1;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleOptionSizeGrip_setCorner_1native_1cref_1Qt_1Corner__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint corner0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QStyleOptionSizeGrip *__qt_this = QtJambiAPI::objectFromNativeId<QStyleOptionSizeGrip>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        Qt::Corner __qt_corner0 = qtjambi_cast<Qt::Corner>(__jni_env, corner0);
        __qt_this->corner = Qt::Corner(__qt_corner0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleOptionSizeGrip_corner_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QStyleOptionSizeGrip *__qt_this = QtJambiAPI::objectFromNativeId<QStyleOptionSizeGrip>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const Qt::Corner&  __qt_value = __qt_this->corner;
        __java_return_value = __qt_value;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleOptionSizeGrip_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QStyleOptionSizeGrip *__qt_this = QtJambiAPI::objectFromNativeId<QStyleOptionSizeGrip>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QStyleOptionSizeGrip(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QStyleOptionSizeGrip>("QStyleOptionSizeGrip", "io/qt/widgets/QStyleOptionSizeGrip");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, 0, &__qt_destruct_QStyleOptionSizeGrip, {
        ConstructorInfo(&__qt_construct_QStyleOptionSizeGrip, nullptr)
       ,ConstructorInfo(&__qt_construct_QStyleOptionSizeGrip_cref_QStyleOptionSizeGrip, "Lio/qt/widgets/QStyleOptionSizeGrip;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QStyleOptionSizeGrip);
    registerMetaType<QStyleOptionSizeGrip>("QStyleOptionSizeGrip");
    registerSizeOfShell(typeId, sizeof(QStyleOptionSizeGrip_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerPolymorphyHandler(typeid(QStyleOptionComplex), typeId, [](void *ptr, qintptr& offset) -> bool {
            QStyleOptionComplex *object = reinterpret_cast<QStyleOptionComplex *>(ptr);
            Q_ASSERT(object);
            offset = 0;
            bool _result = false;
            QTJAMBI_TRY_ANY { // cast from baseclass
                _result = object->type == QStyleOptionSizeGrip::Type;
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerPolymorphyHandler(typeid(QStyleOption), typeId, [](void *ptr, qintptr& offset) -> bool {
            QStyleOption *object = reinterpret_cast<QStyleOption *>(ptr);
            Q_ASSERT(object);
            offset = 0;
            bool _result = false;
            QTJAMBI_TRY_ANY { // cast from baseclass
                _result = object->type == QStyleOptionSizeGrip::Type;
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
